@@ -52,16 +52,19 @@ adducts095 =  dbdi.identify_adducts(raw_imp, annotation_metadata["ThMass.Ion"],
 
 
 #%%setup import from mgf
-import os
+import time
 from matchms.importing import load_from_mgf
 
 
-path_data = "C:/Users/weidner.leopold/Nextcloud/Project212/src/data/"  
+path_data = "/Users/lw/Nextcloud/Project212/src/data"  
 file_mgf = os.path.join(path_data, "example_dataset.mgf")
 spectrums = list(load_from_mgf(file_mgf))
 
-testXX = align_spectra(spectrums)
 
+starttime = time.process_time()
+testXX = dbdi.align_spectra(spectrums)
+elapsed = time.process_time() - starttime
+print(elapsed)   ##7.24 sec
 
 #%% import-export-cylce
 
